@@ -1,40 +1,27 @@
 /*
- * Copyright (C) 2014  Daniel Vrátil <dvratil@redhat.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-FileCopyrightText: 2014 Daniel Vrátil <dvratil@redhat.com>
  *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "pagecreatejob.h"
-#include "page.h"
-#include "bloggerservice.h"
-#include "utils.h"
 #include "account.h"
+#include "bloggerservice.h"
+#include "page.h"
+#include "utils.h"
 
-#include <QNetworkRequest>
 #include <QNetworkReply>
+#include <QNetworkRequest>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Blogger;
 
 class Q_DECL_HIDDEN PageCreateJob::Private
 {
-  public:
+public:
     Private(const PagePtr &page);
 
-    PagePtr page;
+    const PagePtr page;
 };
 
 PageCreateJob::Private::Private(const PagePtr &page_)
@@ -42,9 +29,7 @@ PageCreateJob::Private::Private(const PagePtr &page_)
 {
 }
 
-PageCreateJob::PageCreateJob(const PagePtr &page,
-                             const AccountPtr &account,
-                             QObject *parent)
+PageCreateJob::PageCreateJob(const PagePtr &page, const AccountPtr &account, QObject *parent)
     : CreateJob(account, parent)
     , d(new Private(page))
 {
@@ -58,9 +43,7 @@ PageCreateJob::~PageCreateJob()
 void PageCreateJob::start()
 {
     const QUrl url = BloggerService::createPageUrl(d->page->blogId());
-    QNetworkRequest request;
-    request.setRawHeader("Authorization", "Bearer " + account()->accessToken().toLatin1());
-    request.setUrl(url);
+    QNetworkRequest request(url);
 
     const QByteArray rawData = Page::toJSON(d->page);
 
@@ -83,6 +66,3 @@ ObjectsList PageCreateJob::handleReplyWithItems(const QNetworkReply *reply, cons
     emitFinished();
     return items;
 }
-
-
-
