@@ -1,27 +1,14 @@
 /*
- * Copyright (C) 2014  Daniel Vrátil <dvratil@redhat.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-FileCopyrightText: 2014 Daniel Vrátil <dvratil@redhat.com>
  *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "pagemodifyjob.h"
-#include "page.h"
-#include "bloggerservice.h"
-#include "utils.h"
 #include "account.h"
+#include "bloggerservice.h"
+#include "page.h"
+#include "utils.h"
 
 #include <QNetworkReply>
 #include <QNetworkRequest>
@@ -31,10 +18,10 @@ using namespace KGAPI2::Blogger;
 
 class Q_DECL_HIDDEN PageModifyJob::Private
 {
-  public:
+public:
     Private(const PagePtr &page);
 
-    PagePtr page;
+    const PagePtr page;
 };
 
 PageModifyJob::Private::Private(const PagePtr &page_)
@@ -42,9 +29,7 @@ PageModifyJob::Private::Private(const PagePtr &page_)
 {
 }
 
-PageModifyJob::PageModifyJob(const PagePtr &page,
-                             const AccountPtr &account,
-                             QObject *parent)
+PageModifyJob::PageModifyJob(const PagePtr &page, const AccountPtr &account, QObject *parent)
     : ModifyJob(account, parent)
     , d(new Private(page))
 {
@@ -55,13 +40,10 @@ PageModifyJob::~PageModifyJob()
     delete d;
 }
 
-
 void PageModifyJob::start()
 {
     const QUrl url = BloggerService::modifyPageUrl(d->page->blogId(), d->page->id());
-    QNetworkRequest request;
-    request.setRawHeader("Authorization", "Bearer " + account()->accessToken().toLatin1());
-    request.setUrl(url);
+    QNetworkRequest request(url);
 
     const QByteArray rawData = Page::toJSON(d->page);
     enqueueRequest(request, rawData, QStringLiteral("application/json"));
@@ -83,5 +65,3 @@ ObjectsList PageModifyJob::handleReplyWithItems(const QNetworkReply *reply, cons
     emitFinished();
     return items;
 }
-
-
