@@ -1,87 +1,69 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "contactfetchjob.h"
+#include "account.h"
 #include "contact.h"
 #include "contactsservice.h"
-#include "../debug.h"
+#include "debug.h"
 #include "utils.h"
-#include "account.h"
-
-#include <QtNetwork/QNetworkRequest>
-#include <QtNetwork/QNetworkReply>
 
+#include <QNetworkReply>
+#include <QNetworkRequest>
+#include <QUrlQuery>
 
 using namespace KGAPI2;
 
 class Q_DECL_HIDDEN ContactFetchJob::Private
 {
-  public:
+public:
     Private(ContactFetchJob *parent);
 
     QNetworkRequest createRequest(const QUrl &url);
 
-    bool fetchDeleted;
+    bool fetchDeleted = true;
     QString contactId;
-    quint64 timestamp;
+    quint64 timestamp = 0;
     QString filter;
 
-  private:
-    ContactFetchJob * const q;
+private:
+    ContactFetchJob *const q;
 };
 
-ContactFetchJob::Private::Private(ContactFetchJob *parent):
-    fetchDeleted(true),
-    timestamp(0),
-    q(parent)
+ContactFetchJob::Private::Private(ContactFetchJob *parent)
+    : q(parent)
 {
 }
 
-QNetworkRequest ContactFetchJob::Private::createRequest(const QUrl& url)
+QNetworkRequest ContactFetchJob::Private::createRequest(const QUrl &url)
 {
-    QNetworkRequest request;
-    request.setRawHeader("Authorization", "Bearer " + q->account()->accessToken().toLatin1());
+    QNetworkRequest request(url);
     request.setRawHeader("GData-Version", ContactsService::APIVersion().toLatin1());
-    request.setUrl(url);
 
     QStringList headers;
     auto rawHeaderList = request.rawHeaderList();
     headers.reserve(rawHeaderList.size());
-    Q_FOREACH(const QByteArray &str, rawHeaderList) {
+    for (const QByteArray &str : std::as_const(rawHeaderList)) {
         headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
     }
-    qCDebug(KGAPIRaw) << headers;
 
     return request;
 }
 
-ContactFetchJob::ContactFetchJob(const AccountPtr& account, QObject* parent):
-    FetchJob(account, parent),
-    d(new Private(this))
+ContactFetchJob::ContactFetchJob(const AccountPtr &account, QObject *parent)
+    : FetchJob(account, parent)
+    , d(new Private(this))
 {
 }
 
-ContactFetchJob::ContactFetchJob(const QString& contactId, const AccountPtr& account, QObject* parent):
-    FetchJob(account, parent),
-    d(new Private(this))
+ContactFetchJob::ContactFetchJob(const QString &contactId, const AccountPtr &account, QObject *parent)
+    : FetchJob(account, parent)
+    , d(new Private(this))
 {
     d->contactId = contactId;
 }
@@ -141,12 +123,14 @@ void ContactFetchJob::start()
     QUrl url;
     if (d->contactId.isEmpty()) {
         url = ContactsService::fetchAllContactsUrl(account()->accountName(), d->fetchDeleted);
+        QUrlQuery query(url);
         if (d->timestamp > 0) {
-            url.addQueryItem(QStringLiteral("updated-min"), Utils::ts2Str(d->timestamp));
+            query.addQueryItem(QStringLiteral("updated-min"), Utils::ts2Str(d->timestamp));
         }
         if (!d->filter.isEmpty()) {
-            url.addQueryItem(QStringLiteral("q"), d->filter);
+            query.addQueryItem(QStringLiteral("q"), d->filter);
         }
+        url.setQuery(query);
     } else {
         url = ContactsService::fetchContactUrl(account()->accountName(), d->contactId);
     }
@@ -159,12 +143,11 @@ ObjectsList ContactFetchJob::handleReplyWithItems(const QNetworkReply *reply, co
 {
     FeedData feedData;
     ObjectsList items;
-    QString itemId;
     const QString contentType = reply->header(QNetworkRequest::ContentTypeHeader).toString();
     ContentType ct = Utils::stringToContentType(contentType);
     if (ct == KGAPI2::JSON) {
         if (d->contactId.isEmpty()) {
-            items =  ContactsService::parseJSONFeed(rawData, feedData);
+            items = ContactsService::parseJSONFeed(rawData, feedData);
         } else {
             items << ContactsService::JSONToContact(rawData);
         }
@@ -183,6 +166,3 @@ ObjectsList ContactFetchJob::handleReplyWithItems(const QNetworkReply *reply, co
 
     return ObjectsList();
 }
-
-
-
