@@ -1,29 +1,17 @@
 /*
-    Copyright 2012  Andrius da Costa Ribas <andriusmao@gmail.com>
+    SPDX-FileCopyrightText: 2012 Andrius da Costa Ribas <andriusmao@gmail.com>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef LIBKGAPI2_DRIVE_CHANGE_H
-#define LIBKGAPI2_DRIVE_CHANGE_H
+#pragma once
 
-#include "types.h"
-#include "object.h"
 #include "kgapidrive_export.h"
+#include "object.h"
+#include "types.h"
 
-#include <QtCore/QString>
-#include <QtCore/QUrl>
+#include <QString>
+#include <QUrl>
 
 namespace KGAPI2
 {
@@ -41,12 +29,17 @@ namespace Drive
  * @author Andrius da Costa Ribas <andriusmao@gmail.com>
  * @author Daniel Vrátil <dvratil@redhat.com>
  */
-class KGAPIDRIVE_EXPORT Change: public KGAPI2::Object
+class KGAPIDRIVE_EXPORT Change : public KGAPI2::Object
 {
-  public:
+public:
     explicit Change();
-    explicit Change(const Change& other);
-    virtual ~Change();
+    explicit Change(const Change &other);
+    ~Change() override;
+    bool operator==(const Change &other) const;
+    bool operator!=(const Change &other) const
+    {
+        return !operator==(other);
+    }
 
     /**
      * @brief Returns the id of the change.
@@ -78,14 +71,13 @@ class KGAPIDRIVE_EXPORT Change: public KGAPI2::Object
     static ChangePtr fromJSON(const QByteArray &jsonData);
     static ChangesList fromJSONFeed(const QByteArray &jsonData, FeedData &feedData);
 
-  private:
+private:
     class Private;
-    Private * const d;
+    Private *const d;
     friend class Private;
+    friend class File;
 };
 
 } /* namespace Drive */
 
 } /* namespace KGAPI2 */
-
-#endif // LIBKGAPI2_DRIVE_CHANGE_H
