@@ -1,86 +1,58 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "changefetchjob.h"
 #include "account.h"
 #include "change.h"
-#include "../debug.h"
+#include "debug.h"
 #include "driveservice.h"
 #include "utils.h"
 
-#include <QtNetwork/QNetworkReply>
-#include <QtNetwork/QNetworkRequest>
-
+#include <QNetworkReply>
+#include <QNetworkRequest>
+#include <QUrlQuery>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
 
 class Q_DECL_HIDDEN ChangeFetchJob::Private
 {
-  public:
+public:
     Private(ChangeFetchJob *parent);
-    QNetworkRequest createRequest(const QUrl &url);
 
     QString changeId;
 
-    bool includeDeleted;
-    bool includeSubscribed;
-    int maxResults;
-    qlonglong startChangeId;
+    bool includeDeleted = true;
+    bool includeSubscribed = true;
+    int maxResults = 0;
+    qlonglong startChangeId = 0;
+    bool includeItemsFromAllDrives = true;
+    bool supportsAllDrives = true;
 
-  private:
-    ChangeFetchJob *q;
+private:
+    ChangeFetchJob *const q;
 };
 
-ChangeFetchJob::Private::Private(ChangeFetchJob *parent):
-    includeDeleted(true),
-    includeSubscribed(true),
-    maxResults(0),
-    startChangeId(0),
-    q(parent)
+ChangeFetchJob::Private::Private(ChangeFetchJob *parent)
+    : q(parent)
 {
 }
 
-QNetworkRequest ChangeFetchJob::Private::createRequest(const QUrl &url)
-{
-    QNetworkRequest request;
-    request.setRawHeader("Authorization", "Bearer " + q->account()->accessToken().toLatin1());
-    request.setUrl(url);
-
-    return request;
-}
-
-
-ChangeFetchJob::ChangeFetchJob(const QString &changeId,
-                               const AccountPtr &account,
-                               QObject *parent):
-    FetchJob(account, parent),
-    d(new Private(this))
+ChangeFetchJob::ChangeFetchJob(const QString &changeId, const AccountPtr &account, QObject *parent)
+    : FetchJob(account, parent)
+    , d(new Private(this))
 {
     d->changeId = changeId;
 }
 
-ChangeFetchJob::ChangeFetchJob(const AccountPtr &account, QObject *parent):
-    FetchJob(account, parent),
-    d(new Private(this))
+ChangeFetchJob::ChangeFetchJob(const AccountPtr &account, QObject *parent)
+    : FetchJob(account, parent)
+    , d(new Private(this))
 {
 }
 
@@ -148,36 +120,60 @@ qlonglong ChangeFetchJob::startChangeId() const
     return d->startChangeId;
 }
 
+bool ChangeFetchJob::includeItemsFromAllDrives() const
+{
+    return d->includeItemsFromAllDrives;
+}
+
+void ChangeFetchJob::setIncludeItemsFromAllDrives(bool includeItemsFromAllDrives)
+{
+    d->includeItemsFromAllDrives = includeItemsFromAllDrives;
+}
+
+bool ChangeFetchJob::supportsAllDrives() const
+{
+    return d->supportsAllDrives;
+}
+
+void ChangeFetchJob::setSupportsAllDrives(bool supportsAllDrives)
+{
+    d->supportsAllDrives = supportsAllDrives;
+}
+
 void ChangeFetchJob::start()
 {
     QUrl url;
     if (d->changeId.isEmpty()) {
         url = DriveService::fetchChangesUrl();
-        url.addQueryItem(QStringLiteral("includeDeleted"), Utils::bool2Str(d->includeDeleted));
-        url.addQueryItem(QStringLiteral("includeSubscribed"), Utils::bool2Str(d->includeSubscribed));
+        QUrlQuery query(url);
+        query.addQueryItem(QStringLiteral("includeDeleted"), Utils::bool2Str(d->includeDeleted));
+        query.addQueryItem(QStringLiteral("includeSubscribed"), Utils::bool2Str(d->includeSubscribed));
         if (d->maxResults > 0) {
-            url.addQueryItem(QStringLiteral("maxResults"), QString::number(d->maxResults));
+            query.addQueryItem(QStringLiteral("maxResults"), QString::number(d->maxResults));
         }
         if (d->startChangeId > 0) {
-            url.addQueryItem(QStringLiteral("startChangeId"), QString::number(d->startChangeId));
+            query.addQueryItem(QStringLiteral("startChangeId"), QString::number(d->startChangeId));
         }
+        query.addQueryItem(QStringLiteral("includeItemsFromAllDrives"), Utils::bool2Str(d->includeItemsFromAllDrives));
+        url.setQuery(query);
     } else {
         url = DriveService::fetchChangeUrl(d->changeId);
     }
 
-    const QNetworkRequest request = d->createRequest(url);
+    QUrlQuery query(url);
+    query.addQueryItem(QStringLiteral("supportsAllDrives"), Utils::bool2Str(d->supportsAllDrives));
+    url.setQuery(query);
+
+    QNetworkRequest request(url);
     enqueueRequest(request);
 }
 
-
-ObjectsList ChangeFetchJob::handleReplyWithItems(const QNetworkReply *reply,
-        const QByteArray &rawData)
+ObjectsList ChangeFetchJob::handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData)
 {
     FeedData feedData;
-    feedData.requestUrl = reply->request().url();
+    feedData.requestUrl = reply->url();
 
     ObjectsList items;
-    QString itemId;
 
     const QString contentType = reply->header(QNetworkRequest::ContentTypeHeader).toString();
     ContentType ct = Utils::stringToContentType(contentType);
@@ -195,11 +191,9 @@ ObjectsList ChangeFetchJob::handleReplyWithItems(const QNetworkReply *reply,
     }
 
     if (feedData.nextPageUrl.isValid()) {
-        const QNetworkRequest request = d->createRequest(feedData.nextPageUrl);
+        QNetworkRequest request(feedData.nextPageUrl);
         enqueueRequest(request);
     }
 
     return items;
 }
-
-
