@@ -1,77 +1,57 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-
 #include "fileabstractuploadjob.h"
 #include "account.h"
-#include "../debug.h"
+#include "debug.h"
 #include "driveservice.h"
-#include "file.h"
 #include "utils.h"
 
-#include <QNetworkRequest>
 #include <QNetworkReply>
+#include <QNetworkRequest>
 
-#include <QMimeType>
-#include <QMimeDatabase>
-#include <QFile>
 #include <QCryptographicHash>
+#include <QFile>
+#include <QFileInfo>
+#include <QMimeDatabase>
+#include <QMimeType>
+#include <QUrlQuery>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
 
 class Q_DECL_HIDDEN FileAbstractUploadJob::Private
 {
-  public:
+public:
     Private(FileAbstractUploadJob *parent);
     void processNext();
-    QByteArray buildMultipart(const QString &filePath,
-                              const FilePtr &metaData,
-                              QString &boundary);
+    QByteArray buildMultipart(const QString &filePath, const FilePtr &metaData, QString &boundary);
     QByteArray readFile(const QString &filePath, QString &contentType);
 
     void _k_uploadProgress(qint64 bytesSent, qint64 totalBytes);
 
-    int originalFilesCount;
+    int originalFilesCount = 0;
     QMap<QString, FilePtr> files;
 
     QMap<QString, FilePtr> uploadedFiles;
 
-
-    bool useContentAsIndexableText;
     File::SerializationOptions serializationOptions = File::NoOptions;
 
-  private:
+private:
     FileAbstractUploadJob *const q;
 };
 
-FileAbstractUploadJob::Private::Private(FileAbstractUploadJob *parent):
-    originalFilesCount(0),
-    useContentAsIndexableText(false),
-    q(parent)
+FileAbstractUploadJob::Private::Private(FileAbstractUploadJob *parent)
+    : q(parent)
 {
 }
 
-QByteArray FileAbstractUploadJob::Private::readFile(const QString &filePath,
-                                                    QString &contentType)
+QByteArray FileAbstractUploadJob::Private::readFile(const QString &filePath, QString &contentType)
 {
     QFile file(filePath);
     if (!file.open(QIODevice::ReadOnly)) {
@@ -79,9 +59,12 @@ QByteArray FileAbstractUploadJob::Private::readFile(const QString &filePath,
         return QByteArray();
     }
 
-    const QMimeDatabase db;
-    const QMimeType mime = db.mimeTypeForFileNameAndData(filePath, &file);
-    contentType = mime.name();
+    if (contentType.isEmpty()) {
+        const QMimeDatabase db;
+        const QMimeType mime = db.mimeTypeForFileNameAndData(filePath, &file);
+        contentType = mime.name();
+        qCDebug(KGAPIDebug) << "Determined content type" << contentType << "for" << filePath;
+    }
 
     file.reset();
     QByteArray output = file.readAll();
@@ -91,11 +74,9 @@ QByteArray FileAbstractUploadJob::Private::readFile(const QString &filePath,
     return output;
 }
 
-QByteArray FileAbstractUploadJob::Private::buildMultipart(const QString &filePath,
-                                                          const FilePtr &metaData,
-                                                          QString &boundary)
+QByteArray FileAbstractUploadJob::Private::buildMultipart(const QString &filePath, const FilePtr &metaData, QString &boundary)
 {
-    QString fileContentType;
+    QString fileContentType = metaData->mimeType();
     QByteArray fileContent;
 
     fileContent = readFile(filePath, fileContentType);
@@ -103,15 +84,18 @@ QByteArray FileAbstractUploadJob::Private::buildMultipart(const QString &filePat
         return QByteArray();
     }
 
+    qCDebug(KGAPIDebug) << "Setting content type" << fileContentType << "for" << filePath;
+
     // Wannabe implementation of RFC2387, i.e. multipart/related
     QByteArray body;
-    const QByteArray md5 = QCryptographicHash::hash(filePath.toLatin1(), QCryptographicHash::Md5);
+    QFileInfo finfo(filePath);
+    const QByteArray md5 = QCryptographicHash::hash(finfo.fileName().toLatin1(), QCryptographicHash::Md5);
     boundary = QString::fromLatin1(md5.toHex());
 
     body += "--" + boundary.toLatin1() + '\n';
     body += "Content-Type: application/json; charset=UTF-8\n";
     body += '\n';
-    body += File::toJSON(metaData);
+    body += File::toJSON(metaData, q->serializationOptions());
     body += '\n';
     body += '\n';
     body += "--" + boundary.toLatin1() + '\n';
@@ -148,16 +132,15 @@ void FileAbstractUploadJob::Private::processNext()
     }
 
     q->updateUrl(url);
-    url.addQueryItem(QStringLiteral("useContentAsIndexableText"), Utils::bool2Str(useContentAsIndexableText));
+    QUrlQuery query(url);
 
-    QNetworkRequest request;
     QByteArray rawData;
     QString contentType;
 
     // just to be sure
-    url.removeQueryItem(QStringLiteral("uploadType"));
+    query.removeQueryItem(QStringLiteral("uploadType"));
     if (metaData.isNull()) {
-        url.addQueryItem(QStringLiteral("uploadType"), QStringLiteral("media"));
+        query.addQueryItem(QStringLiteral("uploadType"), QStringLiteral("media"));
 
         rawData = readFile(filePath, contentType);
         if (rawData.isEmpty()) {
@@ -166,7 +149,7 @@ void FileAbstractUploadJob::Private::processNext()
         }
 
     } else if (!filePath.startsWith(QLatin1String("?="))) {
-        url.addQueryItem(QStringLiteral("uploadType"), QStringLiteral("multipart"));
+        query.addQueryItem(QStringLiteral("uploadType"), QStringLiteral("multipart"));
 
         QString boundary;
         rawData = buildMultipart(filePath, metaData, boundary);
@@ -181,8 +164,9 @@ void FileAbstractUploadJob::Private::processNext()
         contentType = QStringLiteral("application/json");
     }
 
-    request.setUrl(url);
-    request.setRawHeader("Authorization", "Bearer " + q->account()->accessToken().toLatin1());
+    url.setQuery(query);
+
+    QNetworkRequest request(url);
     request.setHeader(QNetworkRequest::ContentLengthHeader, rawData.length());
     request.setHeader(QNetworkRequest::ContentTypeHeader, contentType);
     request.setAttribute(QNetworkRequest::User, filePath);
@@ -190,80 +174,66 @@ void FileAbstractUploadJob::Private::processNext()
     q->enqueueRequest(request, rawData, contentType);
 }
 
-void FileAbstractUploadJob::Private::_k_uploadProgress(qint64 bytesSent,
-        qint64 totalBytes)
+void FileAbstractUploadJob::Private::_k_uploadProgress(qint64 bytesSent, qint64 totalBytes)
 {
     // Each file consists of 100 units, so if we have two files, one already
     // uploaded and the other one uploaded from 50%, the values are (150, 200)
 
-    int processedParts = (originalFilesCount - files.count()) * 100;
-    int currentFileParts = 100.0 * ((qreal) bytesSent / (qreal) totalBytes);
+    int processedParts = (originalFilesCount - files.count() - 1) * 100;
+    int currentFileParts = 100.0 * ((qreal)bytesSent / (qreal)totalBytes);
 
     q->emitProgress(processedParts + currentFileParts, originalFilesCount * 100);
 }
 
-FileAbstractUploadJob::FileAbstractUploadJob(const FilePtr &metadata,
-                                             const AccountPtr &account,
-                                             QObject *parent):
-    FileAbstractDataJob(account, parent),
-    d(new Private(this))
+FileAbstractUploadJob::FileAbstractUploadJob(const FilePtr &metadata, const AccountPtr &account, QObject *parent)
+    : FileAbstractDataJob(account, parent)
+    , d(new Private(this))
 {
     d->files.insert(QStringLiteral("?=0"), metadata);
     d->originalFilesCount = 1;
 }
 
-FileAbstractUploadJob::FileAbstractUploadJob(const FilesList &metadata,
-                                             const AccountPtr &account,
-                                             QObject *parent):
-    FileAbstractDataJob(account, parent),
-    d(new Private(this))
+FileAbstractUploadJob::FileAbstractUploadJob(const FilesList &metadata, const AccountPtr &account, QObject *parent)
+    : FileAbstractDataJob(account, parent)
+    , d(new Private(this))
 {
     int i = 0;
-    Q_FOREACH (const FilePtr &file, metadata) {
+    for (const FilePtr &file : metadata) {
         d->files.insert(QStringLiteral("?=%1").arg(i), file);
         ++i;
     }
     d->originalFilesCount = d->files.count();
 }
 
-FileAbstractUploadJob::FileAbstractUploadJob(const QString &filePath,
-                                             const AccountPtr &account,
-                                             QObject *parent):
-    FileAbstractDataJob(account, parent),
-    d(new Private(this))
+FileAbstractUploadJob::FileAbstractUploadJob(const QString &filePath, const AccountPtr &account, QObject *parent)
+    : FileAbstractDataJob(account, parent)
+    , d(new Private(this))
 {
     d->files.insert(filePath, FilePtr());
     d->originalFilesCount = 1;
 }
 
-FileAbstractUploadJob::FileAbstractUploadJob(const QString &filePath,
-                                             const FilePtr &metaData,
-                                             const AccountPtr &account,
-                                             QObject *parent):
-    FileAbstractDataJob(account, parent),
-    d(new Private(this))
+FileAbstractUploadJob::FileAbstractUploadJob(const QString &filePath, const FilePtr &metaData, const AccountPtr &account, QObject *parent)
+    : FileAbstractDataJob(account, parent)
+    , d(new Private(this))
 {
     d->files.insert(filePath, metaData);
     d->originalFilesCount = 1;
 }
 
-FileAbstractUploadJob::FileAbstractUploadJob(const QStringList &filePaths,
-                                             const AccountPtr &account,
-                                             QObject *parent):
-    FileAbstractDataJob(account, parent),
-    d(new Private(this))
+FileAbstractUploadJob::FileAbstractUploadJob(const QStringList &filePaths, const AccountPtr &account, QObject *parent)
+    : FileAbstractDataJob(account, parent)
+    , d(new Private(this))
 {
-    Q_FOREACH(const QString & filePath, filePaths) {
+    for (const QString &filePath : filePaths) {
         d->files.insert(filePath, FilePtr());
     }
     d->originalFilesCount = d->files.count();
 }
 
-FileAbstractUploadJob::FileAbstractUploadJob(const QMap< QString, FilePtr > &files,
-                                             const AccountPtr &account,
-                                             QObject *parent):
-    FileAbstractDataJob(account, parent),
-    d(new Private(this))
+FileAbstractUploadJob::FileAbstractUploadJob(const QMap<QString, FilePtr> &files, const AccountPtr &account, QObject *parent)
+    : FileAbstractDataJob(account, parent)
+    , d(new Private(this))
 {
     d->files = files;
     d->originalFilesCount = d->files.count();
@@ -274,26 +244,16 @@ FileAbstractUploadJob::~FileAbstractUploadJob()
     delete d;
 }
 
-void FileAbstractUploadJob::setUseContentAsIndexableText(bool useContentAsIndexableText)
-{
-    if (isRunning()) {
-        qCWarning(KGAPIDebug) << "Can't modify useContentAsIndexableText property when job is running";
-        return;
-    }
-
-    d->useContentAsIndexableText = useContentAsIndexableText;
-}
-
-bool FileAbstractUploadJob::useContentAsIndexableText() const
-{
-    return d->useContentAsIndexableText;
-}
-
 void FileAbstractUploadJob::start()
 {
     d->processNext();
 }
 
+QMap<QString, FilePtr> FileAbstractUploadJob::files() const
+{
+    return d->uploadedFiles;
+}
+
 void FileAbstractUploadJob::dispatchRequest(QNetworkAccessManager *accessManager,
                                             const QNetworkRequest &request,
                                             const QByteArray &data,
@@ -303,12 +263,12 @@ void FileAbstractUploadJob::dispatchRequest(QNetworkAccessManager *accessManager
 
     QNetworkReply *reply = dispatch(accessManager, request, data);
 
-    connect(reply, SIGNAL(uploadProgress(qint64,qint64)),
-            this, SLOT(_k_uploadProgress(qint64,qint64)));
+    connect(reply, &QNetworkReply::uploadProgress, this, [this](qint64 bytesSent, qint64 totalBytes) {
+        d->_k_uploadProgress(bytesSent, totalBytes);
+    });
 }
 
-void FileAbstractUploadJob::handleReply(const QNetworkReply *reply,
-                                        const QByteArray &rawData)
+void FileAbstractUploadJob::handleReply(const QNetworkReply *reply, const QByteArray &rawData)
 {
     const QString contentType = reply->header(QNetworkRequest::ContentTypeHeader).toString();
     ContentType ct = Utils::stringToContentType(contentType);
@@ -339,5 +299,4 @@ File::SerializationOptions FileAbstractUploadJob::serializationOptions() const
     return d->serializationOptions;
 }
 
-
 #include "moc_fileabstractuploadjob.cpp"
