@@ -1,46 +1,35 @@
 /*
-    Copyright 2012  Andrius da Costa Ribas <andriusmao@gmail.com>
+    SPDX-FileCopyrightText: 2012 Andrius da Costa Ribas <andriusmao@gmail.com>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "parentreference.h"
 #include "parentreference_p.h"
+#include "utils_p.h"
 
-#include <QVariantMap>
 #include <QJsonDocument>
+#include <QVariantMap>
 
 using namespace KGAPI2;
 using namespace KGAPI2::Drive;
 
-ParentReference::Private::Private():
-    isRoot(false)
+ParentReference::Private::Private()
+    : isRoot(false)
 {
 }
 
-ParentReference::Private::Private(const Private &other):
-    id(other.id),
-    selfLink(other.selfLink),
-    parentLink(other.parentLink),
-    isRoot(other.isRoot)
+ParentReference::Private::Private(const Private &other)
+    : id(other.id)
+    , selfLink(other.selfLink)
+    , parentLink(other.parentLink)
+    , isRoot(other.isRoot)
 {
 }
 
 ParentReferencePtr ParentReference::Private::fromJSON(const QVariantMap &map)
 {
-    if (!map.contains(QStringLiteral("kind")) ||
-            map[QStringLiteral("kind")].toString() != QLatin1String("drive#parentReference")) {
+    if (!map.contains(QLatin1String("kind")) || map[QStringLiteral("kind")].toString() != QLatin1String("drive#parentReference")) {
         return ParentReferencePtr();
     }
 
@@ -71,16 +60,16 @@ QVariantMap ParentReference::Private::toJSON(const ParentReferencePtr &reference
     return map;
 }
 
-ParentReference::ParentReference(const QString &id):
-    KGAPI2::Object(),
-    d(new Private)
+ParentReference::ParentReference(const QString &id)
+    : KGAPI2::Object()
+    , d(new Private)
 {
     d->id = id;
 }
 
-ParentReference::ParentReference(const ParentReference &other):
-    KGAPI2::Object(other),
-    d(new Private(*(other.d)))
+ParentReference::ParentReference(const ParentReference &other)
+    : KGAPI2::Object(other)
+    , d(new Private(*(other.d)))
 {
 }
 
@@ -89,6 +78,18 @@ ParentReference::~ParentReference()
     delete d;
 }
 
+bool ParentReference::operator==(const ParentReference &other) const
+{
+    if (!Object::operator==(other)) {
+        return false;
+    }
+    GAPI_COMPARE(id)
+    GAPI_COMPARE(selfLink)
+    GAPI_COMPARE(parentLink)
+    GAPI_COMPARE(isRoot)
+    return true;
+}
+
 QString ParentReference::id() const
 {
     return d->id;
@@ -129,14 +130,13 @@ ParentReferencesList ParentReference::fromJSONFeed(const QByteArray &jsonData)
 
     const QVariant data = document.toVariant();
     const QVariantMap map = data.toMap();
-    if (!map.contains(QStringLiteral("kind")) ||
-            map[QStringLiteral("kind")].toString() != QLatin1String("kind#parentList")) {
+    if (!map.contains(QLatin1String("kind")) || map[QStringLiteral("kind")].toString() != QLatin1String("drive#parentList")) {
         return ParentReferencesList();
     }
 
     ParentReferencesList list;
     const QVariantList items = map[QStringLiteral("items")].toList();
-    Q_FOREACH(const QVariant & item, items) {
+    for (const QVariant &item : items) {
         const ParentReferencePtr reference = Private::fromJSON(item.toMap());
 
         if (!reference.isNull()) {
