@@ -1,30 +1,17 @@
 /*
-    Copyright 2012  Andrius da Costa Ribas <andriusmao@gmail.com>
+    SPDX-FileCopyrightText: 2012 Andrius da Costa Ribas <andriusmao@gmail.com>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef LIBKGAPI2_DRIVEREVISION_H
-#define LIBKGAPI2_DRIVEREVISION_H
+#pragma once
 
-#include "types.h"
-#include "object.h"
 #include "kgapidrive_export.h"
+#include "object.h"
+#include "types.h"
 
-#include <QtCore/QString>
-#include <QtCore/QUrl>
-#include <QtCore/QVariantMap>
+#include <QString>
+#include <QUrl>
 
 #include <QDateTime>
 
@@ -44,13 +31,17 @@ namespace Drive
  * @author Andrius da Costa Ribas <andriusmao@gmail.com>
  * @author Daniel Vrátil <dvratil@redhat.com>
  */
-class KGAPIDRIVE_EXPORT Revision: public KGAPI2::Object
+class KGAPIDRIVE_EXPORT Revision : public KGAPI2::Object
 {
-
-  public:
+public:
     explicit Revision();
     explicit Revision(const Revision &other);
-    virtual ~Revision();
+    ~Revision() override;
+    bool operator==(const Revision &other) const;
+    bool operator!=(const Revision &other) const
+    {
+        return !operator==(other);
+    }
 
     /**
      * @brief Returns the id of the revision.
@@ -127,7 +118,7 @@ class KGAPIDRIVE_EXPORT Revision: public KGAPI2::Object
      *
      * This is only populated and can only be modified for Google Docs.
      *
-     * @param publishedAuto
+     * @param publishAuto
      */
     void setPublishAuto(bool publishAuto);
 
@@ -159,7 +150,7 @@ class KGAPIDRIVE_EXPORT Revision: public KGAPI2::Object
      *
      * This is a map from the export format to URL.
      */
-    QMap < QString /* format */, QUrl /* url */ > exportLinks() const;
+    QMap<QString /* format */, QUrl /* url */> exportLinks() const;
 
     /**
      * @brief Returns the name of the last user to modify this revision.
@@ -196,7 +187,7 @@ class KGAPIDRIVE_EXPORT Revision: public KGAPI2::Object
     static RevisionsList fromJSONFeed(const QByteArray &jsonData);
     static QByteArray toJSON(const RevisionPtr &revision);
 
-  private:
+private:
     class Private;
     Private *const d;
     friend class Private;
@@ -205,5 +196,3 @@ class KGAPIDRIVE_EXPORT Revision: public KGAPI2::Object
 } /* namespace Drive */
 
 } /* namespace KGAPI2 */
-
-#endif // LIBKGAPI2_DRIVEREVISION_H
