@@ -1,32 +1,18 @@
 /*
-    Copyright (C) 2012  Jan Grulich <grulja@gmail.com>
+    SPDX-FileCopyrightText: 2012 Jan Grulich <grulja@gmail.com>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
+#pragma once
 
-#ifndef LIBKGAPI2_OBJECTS_LOCATION_H
-#define LIBKGAPI2_OBJECTS_LOCATION_H
-
+#include "kgapilatitude_export.h"
 #include "object.h"
 #include "types.h"
-#include "kgapilatitude_export.h"
 
 #include <KContacts/Geo>
 
-#include <QtCore/QSharedPointer>
+#include <QSharedPointer>
 
 namespace KGAPI2
 {
@@ -38,11 +24,9 @@ namespace KGAPI2
  * @author Jan Grulich <grulja@gmail.com>
  * @since 0.4
  */
-class KGAPILATITUDE_EXPORT Location : public KGAPI2::Object,
-                                      public KContacts::Geo
+class KGAPILATITUDE_DEPRECATED_EXPORT Location : public KGAPI2::Object, public KContacts::Geo
 {
-  public:
-
+public:
     /**
      * @brief Constructor
      */
@@ -64,7 +48,7 @@ class KGAPILATITUDE_EXPORT Location : public KGAPI2::Object,
     /**
      * @brief Destructor
      */
-    virtual ~Location();
+    ~Location() override;
 
     /**
      * @brief Timestamp of when this location has been recorded.
@@ -76,7 +60,7 @@ class KGAPILATITUDE_EXPORT Location : public KGAPI2::Object,
     /**
      * @brief Sets timestamp of this location.
      */
-    void setTimestamp(const qulonglong &timestamp);
+    void setTimestamp(qulonglong timestamp);
 
     /**
      * @brief Returns accuracy of the latitude and longitude in meters.
@@ -88,7 +72,7 @@ class KGAPILATITUDE_EXPORT Location : public KGAPI2::Object,
     /**
      * @brief Sets accuracy of this location.
      */
-    void setAccuracy(const qint32 &accuracy);
+    void setAccuracy(qint32 accuracy);
 
     /**
      * @brief Returns ground speed of the user at the time this location was
@@ -101,7 +85,7 @@ class KGAPILATITUDE_EXPORT Location : public KGAPI2::Object,
     /**
      * @brief Sets speed of this location.
      */
-    void setSpeed(const qint32 &speed);
+    void setSpeed(qint32 speed);
 
     /**
      * @brief Returns direction of travel of the user when this location was
@@ -114,7 +98,7 @@ class KGAPILATITUDE_EXPORT Location : public KGAPI2::Object,
     /**
      * @brief Sets heading of this location.
      */
-    void setHeading(const qint32 &heading);
+    void setHeading(qint32 heading);
 
     /**
      * @brief Returns altitude of this location.
@@ -126,7 +110,7 @@ class KGAPILATITUDE_EXPORT Location : public KGAPI2::Object,
     /**
      * @brief Sets altitude of this location.
      */
-    void setAltitude(const qint32 &altitude);
+    void setAltitude(qint32 altitude);
 
     /**
      * @brief Returns altitude accuracy.
@@ -138,15 +122,12 @@ class KGAPILATITUDE_EXPORT Location : public KGAPI2::Object,
     /**
      * @brief Sets altitude accuracy of this location.
      */
-    void setAltitudeAccuracy(const qint32 &altitudeAccuracy);
+    void setAltitudeAccuracy(qint32 altitudeAccuracy);
 
-  private:
+private:
     class Private;
-    Private * const d;
+    Private *const d;
     friend class Private;
-
 };
 
 } // namespace KGAPI2
-
-#endif // LOCATION_H
