@@ -1,32 +1,19 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef LIBKGAPI2_LOCATIONFETCHHISTORYJOB_H
-#define LIBKGAPI2_LOCATIONFETCHHISTORYJOB_H
+#pragma once
 
 #include "fetchjob.h"
-#include "latitude.h"
 #include "kgapilatitude_export.h"
+#include "latitude.h"
 
-namespace KGAPI2 {
+namespace KGAPI2
+{
 
 /**
  * @brief A job to fetch all past locations from user's account on Google Latitude
@@ -34,7 +21,7 @@ namespace KGAPI2 {
  * @author Daniel Vrátil <dvratil@redhat.com>
  * @since 2.0
  */
-class KGAPILATITUDE_EXPORT LocationFetchHistoryJob : public KGAPI2::FetchJob
+class KGAPILATITUDE_DEPRECATED_EXPORT LocationFetchHistoryJob : public KGAPI2::FetchJob
 {
     Q_OBJECT
 
@@ -84,8 +71,7 @@ class KGAPILATITUDE_EXPORT LocationFetchHistoryJob : public KGAPI2::FetchJob
      */
     Q_PROPERTY(qlonglong maxTimestamp READ maxTimestamp WRITE setMaxTimestamp)
 
-  public:
-
+public:
     /**
      * @brief Constructs a job that will fetch all past user's locations from
      *        Google Latitude service
@@ -93,12 +79,12 @@ class KGAPILATITUDE_EXPORT LocationFetchHistoryJob : public KGAPI2::FetchJob
      * @param account Account to authenticate the requests
      * @param parent
      */
-    explicit LocationFetchHistoryJob(const AccountPtr &account, QObject* parent = Q_NULLPTR);
+    explicit LocationFetchHistoryJob(const AccountPtr &account, QObject *parent = nullptr);
 
     /**
      * @brief Destructor
      */
-    virtual ~LocationFetchHistoryJob();
+    ~LocationFetchHistoryJob() override;
 
     /**
      * @brief Returns granularity of the requested locations.
@@ -148,12 +134,11 @@ class KGAPILATITUDE_EXPORT LocationFetchHistoryJob : public KGAPI2::FetchJob
      */
     void setMaxTimestamp(qlonglong maxTimestamp);
 
-  protected:
-
+protected:
     /**
      * @brief KGAPI2::Job::start implementation
      */
-    virtual void start();
+    void start() override;
 
     /**
      * @brief KGAPI2::Job::handleReplyWithItems
@@ -161,16 +146,12 @@ class KGAPILATITUDE_EXPORT LocationFetchHistoryJob : public KGAPI2::FetchJob
      * @param reply
      * @param rawData
      */
-    virtual ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-                                             const QByteArray& rawData);
+    ObjectsList handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData) override;
 
-  private:
+private:
     class Private;
-    Private * const d;
+    Private *const d;
     friend class Private;
-
 };
 
 } // namespace KGAPI2
-
-#endif // LIBKGAPI2_LOCATIONFETCHHISTORYJOB_H
