@@ -1,19 +1,7 @@
 /*
-    Copyright (C) 2012  Jan Grulich <grulja@gmail.com>
+    SPDX-FileCopyrightText: 2012 Jan Grulich <grulja@gmail.com>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License along
-    with this program; if not, write to the Free Software Foundation, Inc.,
-    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "staticmapmarker.h"
@@ -28,10 +16,10 @@ public:
 
     void init(const Private &other);
 
-    LocationType locationType;
-    MarkerSize size;
+    LocationType locationType = StaticMapMarker::Undefined;
+    MarkerSize size = StaticMapMarker::Normal;
 
-    QColor color;
+    QColor color = Qt::red;
     QChar label;
 
     QStringList locationsString;
@@ -39,13 +27,11 @@ public:
     QList<KContacts::Geo> locationsGeo;
 };
 
-StaticMapMarker::Private::Private():
-    locationType(StaticMapMarker::Undefined),
-    size(StaticMapMarker::Normal),
-    color(Qt::red)
-{ }
+StaticMapMarker::Private::Private()
+{
+}
 
-StaticMapMarker::Private::Private(const Private & other)
+StaticMapMarker::Private::Private(const Private &other)
 {
     init(other);
 }
@@ -61,13 +47,13 @@ void StaticMapMarker::Private::init(const Private &other)
     locationsGeo = other.locationsGeo;
 }
 
-StaticMapMarker::StaticMapMarker():
-    d(new Private)
+StaticMapMarker::StaticMapMarker()
+    : d(new Private)
 {
 }
 
-StaticMapMarker::StaticMapMarker (const QString& address, const QChar& label, const MarkerSize size, const QColor& color):
-    d(new Private)
+StaticMapMarker::StaticMapMarker(const QString &address, const QChar &label, const MarkerSize size, const QColor &color)
+    : d(new Private)
 {
     QStringList list;
     list << address;
@@ -78,8 +64,8 @@ StaticMapMarker::StaticMapMarker (const QString& address, const QChar& label, co
     d->color = color;
 }
 
-StaticMapMarker::StaticMapMarker (const KContacts::Address& address, const QChar& label, const MarkerSize size, const QColor& color):
-    d(new Private)
+StaticMapMarker::StaticMapMarker(const KContacts::Address &address, QChar label, const MarkerSize size, const QColor &color)
+    : d(new Private)
 {
     KContacts::Address::List list;
     list << address;
@@ -90,8 +76,8 @@ StaticMapMarker::StaticMapMarker (const KContacts::Address& address, const QChar
     d->color = color;
 }
 
-StaticMapMarker::StaticMapMarker (const KContacts::Geo& address, const QChar& label, const MarkerSize size, const QColor& color):
-    d(new Private)
+StaticMapMarker::StaticMapMarker(const KContacts::Geo &address, QChar label, const MarkerSize size, const QColor &color)
+    : d(new Private)
 {
     QList<KContacts::Geo> list;
     list << address;
@@ -102,9 +88,8 @@ StaticMapMarker::StaticMapMarker (const KContacts::Geo& address, const QChar& la
     d->color = color;
 }
 
-StaticMapMarker::StaticMapMarker(const QStringList & locations, const QChar& label,
-                                 const MarkerSize size, const QColor& color):
-    d(new Private)
+StaticMapMarker::StaticMapMarker(const QStringList &locations, QChar label, const MarkerSize size, const QColor &color)
+    : d(new Private)
 {
     d->locationType = String;
     d->locationsString = locations;
@@ -113,9 +98,8 @@ StaticMapMarker::StaticMapMarker(const QStringList & locations, const QChar& lab
     d->color = color;
 }
 
-StaticMapMarker::StaticMapMarker(const KContacts::Address::List & locations, const QChar& label,
-                                 const MarkerSize size, const QColor& color):
-    d(new Private)
+StaticMapMarker::StaticMapMarker(const KContacts::Address::List &locations, QChar label, const MarkerSize size, const QColor &color)
+    : d(new Private)
 {
     d->locationType = KABCAddress;
     d->locationsAddress = locations;
@@ -124,9 +108,8 @@ StaticMapMarker::StaticMapMarker(const KContacts::Address::List & locations, con
     d->color = color;
 }
 
-StaticMapMarker::StaticMapMarker(const QList< KContacts::Geo >& locations, const QChar& label,
-                                 const MarkerSize size, const QColor& color):
-    d(new Private)
+StaticMapMarker::StaticMapMarker(const QList<KContacts::Geo> &locations, QChar label, const MarkerSize size, const QColor &color)
+    : d(new Private)
 {
     d->locationType = KABCGeo;
     d->locationsGeo = locations;
@@ -135,8 +118,8 @@ StaticMapMarker::StaticMapMarker(const QList< KContacts::Geo >& locations, const
     d->color = color;
 }
 
-StaticMapMarker::StaticMapMarker(const StaticMapMarker& other):
-    d(new Private(*(other.d)))
+StaticMapMarker::StaticMapMarker(const StaticMapMarker &other)
+    : d(new Private(*(other.d)))
 {
 }
 
@@ -155,7 +138,7 @@ QColor StaticMapMarker::color() const
     return d->color;
 }
 
-void StaticMapMarker::setColor(const QColor& color)
+void StaticMapMarker::setColor(const QColor &color)
 {
     d->color = color;
 }
@@ -170,7 +153,7 @@ QChar StaticMapMarker::label() const
     return d->label;
 }
 
-void StaticMapMarker::setLabel(const QChar& label)
+void StaticMapMarker::setLabel(QChar label)
 {
     d->label = label;
 }
@@ -180,7 +163,7 @@ QStringList StaticMapMarker::locationsString() const
     return d->locationsString;
 }
 
-void StaticMapMarker::setLocation(const QString& location)
+void StaticMapMarker::setLocation(const QString &location)
 {
     d->locationType = String;
     d->locationsString.clear();
@@ -189,7 +172,7 @@ void StaticMapMarker::setLocation(const QString& location)
     d->locationsGeo.clear();
 }
 
-void StaticMapMarker::setLocations(const QStringList& locations)
+void StaticMapMarker::setLocations(const QStringList &locations)
 {
     d->locationType = KABCAddress;
     d->locationsString = locations;
@@ -202,7 +185,7 @@ KContacts::Address::List StaticMapMarker::locationsAddress() const
     return d->locationsAddress;
 }
 
-void StaticMapMarker::setLocation(const KContacts::Address& location)
+void StaticMapMarker::setLocation(const KContacts::Address &location)
 {
     d->locationType = KABCAddress;
     d->locationsAddress.clear();
@@ -219,12 +202,12 @@ void StaticMapMarker::setLocations(const KContacts::Address::List &locations)
     d->locationsGeo.clear();
 }
 
-QList< KContacts::Geo > StaticMapMarker::locationsGeo() const
+QList<KContacts::Geo> StaticMapMarker::locationsGeo() const
 {
     return d->locationsGeo;
 }
 
-void StaticMapMarker::setLocation(const KContacts::Geo& location)
+void StaticMapMarker::setLocation(const KContacts::Geo &location)
 {
     d->locationType = KABCGeo;
     d->locationsGeo.clear();
@@ -233,7 +216,7 @@ void StaticMapMarker::setLocation(const KContacts::Geo& location)
     d->locationsAddress.clear();
 }
 
-void StaticMapMarker::setLocations(const QList< KContacts::Geo >& locations)
+void StaticMapMarker::setLocations(const QList<KContacts::Geo> &locations)
 {
     d->locationType = KABCGeo;
     d->locationsGeo = locations;
@@ -269,44 +252,40 @@ QString StaticMapMarker::toString() const
         break;
     }
 
-    if (d->color != Qt::red)
-        ret += QLatin1String("color:") + d->color.name().replace(QLatin1Char('#'), QLatin1String("0x")) + QLatin1String("|");
+    if (d->color != Qt::red) {
+        ret += QLatin1String("color:") + d->color.name().replace(QLatin1Char('#'), QLatin1String("0x")) + QLatin1Char('|');
+    }
 
-    if (d->label.isLetterOrNumber() && d->size > 1)
-        ret += QLatin1String("label:") + d->label.toUpper() + QLatin1String("|");
+    if (d->label.isLetterOrNumber() && d->size > 1) {
+        ret += QLatin1String("label:") + d->label.toUpper() + QLatin1Char('|');
+    }
 
     if (d->locationType == String) {
-
-        Q_FOREACH(const QString & addr, d->locationsString) {
-            ret += addr + QLatin1String("|");
+        for (const QString &addr : std::as_const(d->locationsString)) {
+            ret += addr + QLatin1Char('|');
         }
 
     } else if (d->locationType == KABCAddress) {
-
-        Q_FOREACH(const KContacts::Address & addr, d->locationsAddress) {
-            ret += addr.formattedAddress() + QLatin1String("|");
+        for (const KContacts::Address &addr : std::as_const(d->locationsAddress)) {
+            ret += addr.formatted(KContacts::AddressFormatStyle::Postal) + QLatin1Char('|');
         }
 
     } else if (d->locationType == KABCGeo) {
-
-        Q_FOREACH(const KContacts::Geo & addr, d->locationsGeo) {
-            ret += QString::number(addr.latitude()) + QLatin1String(",") +
-                  QString::number(addr.longitude()) + QLatin1String("|");
+        for (const KContacts::Geo &addr : std::as_const(d->locationsGeo)) {
+            ret += QString::number(addr.latitude()) + QLatin1Char(',') + QString::number(addr.longitude()) + QLatin1Char('|');
         }
-
     }
 
-    ret = ret.replace(QLatin1String(", "), QLatin1String(","));
-    ret = ret.replace(QLatin1String(". "), QLatin1String("."));
-    ret = ret.replace(QLatin1Char(' '), QLatin1Char('+'));
-    ret = ret.replace(QLatin1Char('\n'), QLatin1Char(','));
-    ret = ret.remove(ret.lastIndexOf(QLatin1Char('|')), 1);
+    ret.replace(QLatin1String(", "), QLatin1String(","));
+    ret.replace(QLatin1String(". "), QLatin1String("."));
+    ret.replace(QLatin1Char(' '), QLatin1Char('+'));
+    ret.replace(QLatin1Char('\n'), QLatin1Char(','));
+    ret.remove(ret.lastIndexOf(QLatin1Char('|')), 1);
 
     return ret;
-
 }
 
-StaticMapMarker& StaticMapMarker::operator=(const StaticMapMarker& other)
+StaticMapMarker &StaticMapMarker::operator=(const StaticMapMarker &other)
 {
     if (&other == this) {
         return *this;
