@@ -1,106 +1,68 @@
 /*
  * This file is part of LibKGAPI library
  *
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "taskfetchjob.h"
-#include "tasksservice.h"
 #include "account.h"
-#include "../debug.h"
+#include "debug.h"
 #include "task.h"
+#include "tasksservice.h"
 #include "utils.h"
 
-#include <QtNetwork/QNetworkRequest>
-#include <QtNetwork/QNetworkReply>
-
+#include <QNetworkReply>
+#include <QNetworkRequest>
+#include <QUrlQuery>
 
 using namespace KGAPI2;
 
+namespace
+{
+static const auto ShowDeletedParam = QStringLiteral("showDeleted");
+static const auto ShowCompletedParam = QStringLiteral("showCompleted");
+static const auto UpdatedMinParam = QStringLiteral("updatedMin");
+static const auto CompletedMinParam = QStringLiteral("completedMin");
+static const auto CompletedMaxParam = QStringLiteral("completedMax");
+static const auto DueMinParam = QStringLiteral("dueMin");
+static const auto DueMaxParam = QStringLiteral("dueMax");
+
+static constexpr bool FetchDeletedDefault = false;
+static constexpr bool FetchCompletedDefault = false;
+}
+
 class Q_DECL_HIDDEN TaskFetchJob::Private
 {
-  public:
-    Private(TaskFetchJob *parent);
-    QNetworkRequest createRequest(const QUrl &url);
-
+public:
     QString taskId;
     QString taskListId;
-    bool fetchDeleted;
-    bool fetchCompleted;
+    bool fetchDeleted = true;
+    bool fetchCompleted = true;
     quint64 updatedTimestamp;
     quint64 completedMin;
     quint64 completedMax;
     quint64 dueMin;
     quint64 dueMax;
-
-  private:
-    TaskFetchJob * const q;
 };
 
-TaskFetchJob::Private::Private(TaskFetchJob* parent):
-    fetchDeleted(true),
-    fetchCompleted(true),
-    updatedTimestamp(0),
-    completedMin(0),
-    completedMax(0),
-    dueMin(0),
-    dueMax(0),
-    q(parent)
-{
-}
-
-QNetworkRequest TaskFetchJob::Private::createRequest(const QUrl& url)
-{
-    QNetworkRequest request;
-    request.setRawHeader("Authorization", "Bearer " + q->account()->accessToken().toLatin1());
-    request.setUrl(url);
-
-    QStringList headers;
-    const auto rawHeaderList = request.rawHeaderList();
-    headers.reserve(rawHeaderList.size());
-    Q_FOREACH(const QByteArray &str, rawHeaderList) {
-        headers << QLatin1String(str) + QLatin1String(": ") + QLatin1String(request.rawHeader(str));
-    }
-    qCDebug(KGAPIRaw) << headers;
-
-    return request;
-}
-
-TaskFetchJob::TaskFetchJob(const QString& taskListId, const AccountPtr& account, QObject* parent):
-    FetchJob(account, parent),
-    d(new Private(this))
+TaskFetchJob::TaskFetchJob(const QString &taskListId, const AccountPtr &account, QObject *parent)
+    : FetchJob(account, parent)
+    , d(new Private())
 {
     d->taskListId = taskListId;
 }
 
-TaskFetchJob::TaskFetchJob(const QString& taskId, const QString& taskListId,
-                           const AccountPtr& account, QObject* parent):
-    FetchJob(account, parent),
-    d(new Private(this))
+TaskFetchJob::TaskFetchJob(const QString &taskId, const QString &taskListId, const AccountPtr &account, QObject *parent)
+    : FetchJob(account, parent)
+    , d(new Private())
 {
     d->taskId = taskId;
     d->taskListId = taskListId;
 }
 
-TaskFetchJob::~TaskFetchJob()
-{
-    delete d;
-}
+TaskFetchJob::~TaskFetchJob() = default;
 
 void TaskFetchJob::setFetchOnlyUpdated(quint64 timestamp)
 {
@@ -205,43 +167,48 @@ void TaskFetchJob::start()
     QUrl url;
     if (d->taskId.isEmpty()) {
         url = TasksService::fetchAllTasksUrl(d->taskListId);
-        url.addQueryItem(QStringLiteral("showDeleted"), Utils::bool2Str(d->fetchDeleted));
-        url.addQueryItem(QStringLiteral("showCompleted"), Utils::bool2Str(d->fetchCompleted));
+        QUrlQuery query(url);
+        if (d->fetchDeleted != FetchDeletedDefault) {
+            query.addQueryItem(ShowDeletedParam, Utils::bool2Str(d->fetchDeleted));
+        }
+        if (d->fetchCompleted != FetchCompletedDefault) {
+            query.addQueryItem(ShowCompletedParam, Utils::bool2Str(d->fetchCompleted));
+        }
         if (d->updatedTimestamp > 0) {
-            url.addQueryItem(QStringLiteral("updatedMin"), Utils::ts2Str(d->updatedTimestamp));
+            query.addQueryItem(UpdatedMinParam, Utils::ts2Str(d->updatedTimestamp));
         }
         if (d->completedMin > 0) {
-            url.addQueryItem(QStringLiteral("completedMin"), Utils::ts2Str(d->completedMin));
+            query.addQueryItem(CompletedMinParam, Utils::ts2Str(d->completedMin));
         }
         if (d->completedMax > 0) {
-            url.addQueryItem(QStringLiteral("completedMax"), Utils::ts2Str(d->completedMax));
+            query.addQueryItem(CompletedMaxParam, Utils::ts2Str(d->completedMax));
         }
         if (d->dueMin > 0) {
-            url.addQueryItem(QStringLiteral("dueMin"), Utils::ts2Str(d->dueMin));
+            query.addQueryItem(DueMinParam, Utils::ts2Str(d->dueMin));
         }
         if (d->dueMax > 0) {
-            url.addQueryItem(QStringLiteral("dueMax"), Utils::ts2Str(d->dueMax));
+            query.addQueryItem(DueMaxParam, Utils::ts2Str(d->dueMax));
         }
+        url.setQuery(query);
     } else {
         url = TasksService::fetchTaskUrl(d->taskListId, d->taskId);
     }
 
-    const QNetworkRequest request = d->createRequest(url);
+    const QNetworkRequest request(url);
     enqueueRequest(request);
 }
 
-ObjectsList TaskFetchJob::handleReplyWithItems(const QNetworkReply *reply, const QByteArray& rawData)
+ObjectsList TaskFetchJob::handleReplyWithItems(const QNetworkReply *reply, const QByteArray &rawData)
 {
     FeedData feedData;
-    feedData.requestUrl = reply->request().url();
+    feedData.requestUrl = reply->url();
 
     ObjectsList items;
-    QString itemId;
     const QString contentType = reply->header(QNetworkRequest::ContentTypeHeader).toString();
     ContentType ct = Utils::stringToContentType(contentType);
     if (ct == KGAPI2::JSON) {
         if (d->taskId.isEmpty()) {
-            items =  TasksService::parseJSONFeed(rawData, feedData);
+            items = TasksService::parseJSONFeed(rawData, feedData);
         } else {
             items << TasksService::JSONToTask(rawData);
         }
@@ -253,11 +220,9 @@ ObjectsList TaskFetchJob::handleReplyWithItems(const QNetworkReply *reply, const
     }
 
     if (feedData.nextPageUrl.isValid()) {
-        const QNetworkRequest request = d->createRequest(feedData.nextPageUrl);
+        const QNetworkRequest request(feedData.nextPageUrl);
         enqueueRequest(request);
     }
 
     return items;
 }
-
-
